from classification import Classification

def test_classification_info(class_type, limit):
    try:
        classification_instance = Classification(class_type, limit)
        classification_instance.class_info()
        print(f"Data for classification {class_type} with limit {limit} has been fetched.")
    except ValueError as e:
        print(e)

test_classification_info(3, 5)




import requests
import json

class Classification(object):
    def __init__(self, class_type, limit):
        if class_type == 1:
            self.classification = "Class+I"
        elif class_type == 2:
            self.classification = "Class+II"
        elif class_type == 3:
            self.classification = "Class+III"
        else:
            raise ValueError("Error: no match found (classification level 1~3)")
        
        self.limit = limit

    def class_info(self):
        url = f'https://api.fda.gov/food/enforcement.json?search=classification:{self.classification}&limit={self.limit}'
        response = requests.get(url)
        
        if response.ok:
            with open("food_reverse_class.json", "w") as outfile:
                json.dump(response.json(), outfile, indent = 4)
        else:
            print(f"Error: {response.status_code} - {response.text}")



from ID import food_reverse
from pytest import fixture

@fixture
def reverse_keys():
    return ["country", "state", "city", "classification",
            "recalling_firm", "product_type", "event_id"]

def test_reverse_info(reverse_keys):
    """Tests an API call to get a reverse info based on event_id"""
    reverse_instance = food_reverse(["85253", "62750"])
    response = reverse_instance.info()

    assert isinstance(response,dict)
    assert response["results"][0]["event_id"] == "85253", "The ID should be in the response"
    assert set(reverse_keys).issubset(response["results"][0].keys()), "All keys should be in the response"

test_reverse_info(["country", "state", "city", "classification",
            "recalling_firm", "product_type", "event_id"])